// Compute the MST (Minimum Spanning Tree) between the T towers in O(T^2).
// This solution takes advantage of the fact that the graph is complete
// (there is an edge between each pair of vertices and we can compute its
// cost).
// Moreover we do not need to store the whole grid, but only the positions
// of the towers. Thus, the total memory consumption is only O(T).

#include <iostream>
#include <limits>
#include <utility>
#include <vector>

using namespace std;

int N;

int square(int x) {
    return x * x;
}

int main() {
    cin >> N;
    // Do not store the whole grid but only towers' positions.
    vector<pair<int, int> > towers;
    for (int i = 0; i < N; i++)
        for (int j = 0; j < N; j++) {
            char type;
            cin >> type;
            if (type == 'T')
                towers.push_back({i, j});
        }
    int n_towers = towers.size();

    // Find the MST.
    int current_vertex = 0;
    int res = 0;
    vector<bool> done(n_towers, false);
    vector<int> dist(n_towers, numeric_limits<int>::max());

    for (int i = 0; i < n_towers - 1; i++)
    {
        // Mark current_vertex as added in the spanning tree.       
        done[current_vertex] = true;
        // Update dist if it is more convenient to reach nodes from current_vertex.
        for (int j = 0; j < n_towers; j++) {
            if (!done[j]) {
                int c = square(towers[current_vertex].first - towers[j].first) +
                        square(towers[current_vertex].second - towers[j].second);
                dist[j] = min(dist[j], c);
            }
        }
        // Find the lightest edge
        int next_vertex = -1;
        for (int j = 0; j < n_towers; j++)
            if (!done[j])
                if (next_vertex == -1 || dist[j] < dist[next_vertex])
                    next_vertex = j;
        // Add the cost to the answer and update the next current vertex.
        res += dist[next_vertex];
        current_vertex = next_vertex;
    }

    cout << res << endl;
}

