#include <assert.h>
#include <stdio.h>
#include <numeric>
#include <set>
#include <vector>

// constraints
#define MAXN 100

using ii = std::pair<int, int>;

// input data
int N, M, i, a, b, max_num_edges;
int D[MAXN];

std::set<ii> edges_left;
std::vector<ii> sol, bestsol;
std::vector<std::set<int>> adj;

void removeEdge(int a, int b) {
    if (a > b) std::swap(a, b);
    edges_left.erase({a, b});
    adj[a].erase(b);
    adj[b].erase(a);
}

void addEdge(int a, int b) {
    if (a > b) std::swap(a, b);
    edges_left.insert({a, b});
    adj[a].insert(b);
    adj[b].insert(a);
}

void bb() {
    // base case: there are no edges left to be considered
    if (edges_left.size() == 0) {
        if (sol.size() > bestsol.size()) {
            bestsol = sol;
        }
        return;
    }

    // get the first edge left in the set
    ii e = *edges_left.begin();

    bool mandatory_choice = false;
    for (int i = 0; i < N; ++i) {
        if (D[i] > adj[i].size()) {
            // can't get to max score
            return;
        }
        // check if there are edges that must be choosen necessarily
        // e.g when a node has a degree equal to the number of edges left
        if (D[i] != 0 && D[i] == (int)adj[i].size()) {
            // change first edge left with mandatory edge
            e = {i, *adj[i].begin()};
            mandatory_choice = true;
        }
    }

    if (!mandatory_choice) {
        auto compare = [&](ii a, ii b) {
            auto f = [&](int a, int b) {
                // return adj[a].size() - D[a] + adj[b].size() - D[b];
                return (adj[a].size() - D[a]) + (adj[b].size() - D[b]);
            };
            int deltaA = f(a.first, a.second);
            int deltaB = f(b.first, b.second);
            return deltaA < deltaB;
        };
        for (ii ij : edges_left) {
            if (compare(ij, e)) {
                e = ij;
            }
        }
    }

    // remove edge from set of edges left
    int a = e.first, b = e.second;
    removeEdge(a, b);
    // first case: choosen edge is used in the solution
    sol.push_back(e);
    int edges_to_remove = 0;
    D[a]--;
    D[b]--;
    if (D[a] == 0) edges_to_remove += adj[a].size();
    if (D[b] == 0) edges_to_remove += adj[b].size();

    // if the best solution hasn't been found yet and this solution can be
    // improved to have max_num_edges edges then branch
    if ((int)bestsol.size() != max_num_edges &&
        (int)sol.size() + (int)edges_left.size() - edges_to_remove >=
            max_num_edges) {
        // find edges that need to be removed
        std::vector<ii> removed;
        if (D[a] == 0)
            for (int u : adj[a]) removed.push_back({a, u});
        if (D[b] == 0)
            for (int u : adj[b]) removed.push_back({b, u});
        for (ii r : removed) removeEdge(r.first, r.second);
        // branch
        bb();
        // add edges previously removed
        for (ii r : removed) addEdge(r.first, r.second);
    }

    // revert changes to solution, removing choosen edge
    D[a]++;
    D[b]++;
    sol.pop_back();

    // second case: choosen edge is removed but is not part of the solution.
    // branch is made only if choice of edge was not mandatory
    if (!mandatory_choice && (int)bestsol.size() != max_num_edges &&
        (int)sol.size() + (int)edges_left.size() >= max_num_edges) {
        bb();
    }

    // revert changes to the set of edges that are left
    addEdge(e.first, e.second);
}

int main() {
    //  uncomment the following lines if you want to read/write from files
    //  freopen("input.txt", "r", stdin);
    //  freopen("output.txt", "w", stdout);

    assert(2 == scanf("%d %d", &N, &M));
    adj.resize(N);
    for (i = 0; i < N; i++) {
        assert(1 == scanf("%d", &D[i]));
        max_num_edges += D[i];
    }
    max_num_edges /= 2;  // best solution must have max_num_edges edges
    for (i = 0; i < M; i++) {
        assert(2 == scanf("%d %d", &a, &b));
        addEdge(a, b);
    }

    // start branch and bound
    bb();

    for (auto ij : bestsol) {
        printf("%d %d\n", ij.first, ij.second);
    }
    return 0;
}
