// binary search for a possible solution in O(N log F) if N is large.
// try every permutation if N is small.

#include <assert.h>
#include <stdio.h>
#include <algorithm>
#include <map>
#include <vector>

// constraints
#define MAXN 100000

#define INF 2000000000

using namespace std;

// input data
int N;
int F[MAXN];
vector<int> answer;

using mit = map<int, int>::const_iterator;

// search element in [lo,hi] closest to hi, returning end if not exists
mit get_in_range(const map<int, int>& m, int lo, int hi) {
    if (hi >= lo) {
        mit i = m.upper_bound(hi);
        if (i == m.begin() or (--i)->first < lo) return m.end();
        return i;
    }
    mit i = m.lower_bound(hi);
    if (i == m.end() or i->first > lo) return m.end();
    return i;
}

// tries to plan a workout without crossing a limit, returns the result
int trybelow(int limit) {
    int S = 0, T = 0;
    map<int, int> FS;
    for (int i = 0; i < N; i++) FS[F[i]] += 1;
    answer.clear();
    mit it;

    while (answer.size() < N) {
        // if it exists, I put the highest straining exercise that stays below
        // the limit
        it = get_in_range(FS, 0, limit - S);
        // otherwise, if it exists, I put the most relaxing exercise that does
        // not send me below zero
        if (it == FS.end()) it = get_in_range(FS, 0, -S);
        // otherwise, if it exists, I put the least relaxing exercise left
        if (it == FS.end()) it = get_in_range(FS, -INF, -S);
        // otherwise, I put the least straining exercise left
        if (it == FS.end()) it = get_in_range(FS, INF, limit - S);
        assert(it != FS.end());
        int nxt = it->first;
        answer.push_back(nxt);
        S = max(S + nxt, 0);
        T = max(T, S);
        FS[nxt] -= 1;
        if (FS[nxt] == 0) FS.erase(nxt);
    }
    return T;
}

// binary search for the best workout
int bsearch(int a, int b) {
    if (a == b) return trybelow(a);
    int c = (a + b) / 2;
    int d = trybelow(c);
    if (d <= c)
        return bsearch(a, d);
    else
        return bsearch(c + 1, d);
}

int tryall() {
    int sol;
    int perm[MAXN];
    answer.resize(N);

    for (int i = 0; i < N; i++) perm[i] = i;
    sol = 1e9;
    do {
        int cost = 0;
        int curr = 0;
        for (int i = 0; i < N; i++) {
            cost += F[perm[i]];
            cost = std::max(cost, 0);
            curr = std::max(curr, cost);
        }
        if (curr < sol) {
            sol = curr;
            for (int i = 0; i < N; i++) answer[i] = F[perm[i]];
        }
    } while (std::next_permutation(perm, perm + N));
    return sol;
}

int main() {
    //  uncomment the following lines if you want to read/write from files
    //  freopen("input.txt", "r", stdin);
    //  freopen("output.txt", "w", stdout);

    assert(1 == scanf("%d", &N));
    for (int i = 0; i < N; i++) assert(1 == scanf("%d", &F[i]));

    printf("%d\n", N <= 10 ? tryall() : bsearch(0, INF));
    for (int i = 0; i < N; i++) printf("%d ", answer[i]);
    printf("\n");
    return 0;
}
